==> libreoffice_4.0.4.orig.tar.xz: libreoffice-4.0.4/stoc/source/registry_tdprovider/tdprop.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <osl/diagnose.h>
#include "base.hxx"

namespace stoc_rdbtdp
{

//__________________________________________________________________________________________________
// virtual
ConstantTypeDescriptionImpl::~ConstantTypeDescriptionImpl()
{
    g_moduleCount.modCnt.release( &g_moduleCount.modCnt );
}

// XTypeDescription
//__________________________________________________________________________________________________
// virtual
TypeClass ConstantTypeDescriptionImpl::getTypeClass()
    throw( RuntimeException )
{
    return TypeClass_CONSTANT;
}
//__________________________________________________________________________________________________
// virtual
OUString ConstantTypeDescriptionImpl::getName()
    throw( RuntimeException )
{
    return _aName;
}

// XConstantTypeDescription
//__________________________________________________________________________________________________
// virtual
Any SAL_CALL ConstantTypeDescriptionImpl::getConstantValue()
    throw( RuntimeException )
{
    return _aValue;
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_4.1.3.orig.tar.xz: libreoffice-4.1.3/stoc/source/registry_tdprovider/tdprop.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <osl/diagnose.h>
#include "base.hxx"

namespace stoc_rdbtdp
{

//__________________________________________________________________________________________________
// virtual
ConstantTypeDescriptionImpl::~ConstantTypeDescriptionImpl() {}

// XTypeDescription
//__________________________________________________________________________________________________
// virtual
TypeClass ConstantTypeDescriptionImpl::getTypeClass()
    throw( RuntimeException )
{
    return TypeClass_CONSTANT;
}
//__________________________________________________________________________________________________
// virtual
OUString ConstantTypeDescriptionImpl::getName()
    throw( RuntimeException )
{
    return _aName;
}

// XConstantTypeDescription
//__________________________________________________________________________________________________
// virtual
Any SAL_CALL ConstantTypeDescriptionImpl::getConstantValue()
    throw( RuntimeException )
{
    return _aValue;
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
